package ejblitecachetestapp.web;

import java.text.DateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Hashtable;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.ejb.Local;
import javax.ejb.PostActivate;
import javax.ejb.PrePassivate;
import javax.ejb.Remove;

import javax.ejb.Stateful;

@Stateful
@Local(TestStatefulBeanLocal.class)
public class TestStatefulBean implements TestStatefulBeanLocal {

	private String name;
	public static int num;

	static Hashtable<String, Integer> counters = new Hashtable<String, Integer>();
	static {
		counters.put("POST_CONSTRUCT", 0);
		counters.put("PRE_DESTROY", 0);
		counters.put("POST_ACTIVATE", 0);
		counters.put("PRE_PASSIVATE", 0);
		counters.put("CONSTRUCTOR", 0);
		counters.put("REMOVE", 0);
		counters.put("TIMEOUT", 0);
	}

	public TestStatefulBean(){
		this.name = "TestStatefulBean#" + num++ ;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public void testStatefulBean() {
		System.out.println("Stateful bean #" + name + " tested.");
		printCounters();
	}

	private void printCounters() {
		System.out.println(counters);
	}

	private synchronized void addCounter(String name) {
		Integer v = counters.get(name);
		if (v == null) {
			System.err.println("Counter is not supported: " + name);
		} else {
			Integer i = v + 1;
			counters.put(name, i);
			System.out.println(String.format(
					"Method [%s] is invoked [%s] time(s).", name, i));
		}
	}

	@PostActivate
	public void postActivate() {
		this.addCounter("POST_ACTIVATE");
	}
	
	

	@PrePassivate
	public void prePassivate() {
		this.addCounter("PRE_PASSIVATE");
	}

	@PostConstruct
	public void postConstruct() {
		this.addCounter("POST_CONSTRUCT");
	}

	@PreDestroy
	public void preDestroy() {
		this.addCounter("PRE_DESTROY");
	}

}
